@@ -64,10 +64,11 @@ class DBSettings(BaseSettings):
 
 
 class S3Settings(BaseSettings):
+    aws_region: str | None = None
+    aws_access_key_id: SecretStr | None = None
+    aws_secret_access_key: SecretStr | None = None
+
     s3_endpoint_url: str | None = None
-    s3_region_name: str | None = None
-    s3_access_key_id: SecretStr = SecretStr('')
-    s3_secret_access_key: SecretStr = SecretStr('')
     s3_addressing_style: Literal['path', 'virtual'] = 'virtual'
     s3_secure: bool = True
     s3_bucket: str | None = None
