@@ -6,11 +6,12 @@ import threading
 import time
 from abc import ABCMeta
 from collections import defaultdict
+from collections.abc import Mapping, MutableMapping, Sequence
 from datetime import date, datetime, timedelta
 from decimal import ROUND_HALF_UP, Decimal
-from http.cookies import BaseCookie, SimpleCookie
+from http.cookies import BaseCookie
 from json import dumps
-from typing import Literal, Mapping, Sequence
+from typing import ClassVar, Literal
 from urllib.parse import urlencode
 
 from python3_commons.serializers.json import CustomJSONEncoder
@@ -23,8 +24,8 @@ class SingletonMeta(ABCMeta):
     A metaclass that creates a Singleton base class when called.
     """
 
-    __instances = {}
-    __locks = defaultdict(threading.Lock)
+    __instances: ClassVar[MutableMapping] = {}
+    __locks: ClassVar[defaultdict] = defaultdict(threading.Lock)
 
     def __call__(cls, *args, **kwargs):
         try:
@@ -34,7 +35,7 @@ class SingletonMeta(ABCMeta):
                 try:
                     return cls.__instances[cls]
                 except KeyError:
-                    instance = super(SingletonMeta, cls).__call__(*args, **kwargs)
+                    instance = super().__call__(*args, **kwargs)
                     cls.__instances[cls] = instance
 
                     return instance
@@ -66,9 +67,10 @@ def tries(times):
                 # noinspection PyBroadException
                 try:
                     return await f(*args, **kwargs)
-                except Exception as exc:
+                except Exception:
                     if _time >= times:
-                        raise exc
+                        raise
+            return None
 
         return wrapper
 
@@ -103,11 +105,7 @@ def request_to_curl(
             curl_cmd.append(shlex.quote(header_line))
 
     if cookies:
-        if isinstance(cookies, SimpleCookie):
-            cookie_str = '; '.join(f'{morsel.key}={morsel.value}' for morsel in cookies.values())
-        else:
-            cookie_str = '; '.join(f'{k}={v}' for k, v in cookies.items())
-
+        cookie_str = '; '.join(f'{k}={v.value}' for k, v in cookies.items())
         curl_cmd.extend(['-b', shlex.quote(cookie_str)])
 
     if json:
