@@ -25,7 +25,7 @@ class ObjectStorage(metaclass=SingletonMeta):
     def __init__(self, settings: S3Settings):
         self._session = aiobotocore.session.get_session()
         config = {
-            'region_name': settings.s3_region_name,
+            'region_name': settings.aws_region,
             'use_ssl': settings.s3_secure,
             'verify': settings.s3_cert_verify,
             'config': Config(s3={'addressing_style': settings.s3_addressing_style}, signature_version='s3v4'),
@@ -34,11 +34,11 @@ class ObjectStorage(metaclass=SingletonMeta):
         if s3_endpoint_url := settings.s3_endpoint_url:
             config['endpoint_url'] = s3_endpoint_url
 
-        if s3_access_key_id := settings.s3_access_key_id:
-            config['aws_access_key_id'] = s3_access_key_id.get_secret_value()
+        if aws_access_key_id := settings.aws_access_key_id:
+            config['aws_access_key_id'] = aws_access_key_id.get_secret_value()
 
-        if s3_secret_access_key := settings.s3_secret_access_key:
-            config['aws_secret_access_key'] = s3_secret_access_key.get_secret_value()
+        if aws_secret_access_key := settings.aws_secret_access_key:
+            config['aws_secret_access_key'] = aws_secret_access_key.get_secret_value()
 
         self._config = config
 
@@ -67,14 +67,13 @@ async def put_object(bucket_name: str, path: str, data: io.BytesIO, length: int,
             await s3_client.put_object(Bucket=bucket_name, Key=path, Body=data, ContentLength=length)
 
             logger.debug(f'Stored object into object storage: {bucket_name}:{path}')
-
-            return f's3://{bucket_name}/{path}'
-
         except Exception as e:
-            logger.error(f'Failed to put object to object storage: {bucket_name}:{path}', exc_info=e)
+            logger.exception(f'Failed to put object to object storage: {bucket_name}:{path}', exc_info=e)
 
             raise
 
+        return f's3://{bucket_name}/{path}'
+
 
 @asynccontextmanager
 async def get_object_stream(bucket_name: str, path: str) -> AsyncGenerator[StreamingBody]:
@@ -89,7 +88,7 @@ async def get_object_stream(bucket_name: str, path: str) -> AsyncGenerator[Strea
             async with response['Body'] as stream:
                 yield stream
         except Exception as e:
-            logger.debug(f'Failed getting object from object storage: {bucket_name}:{path}', exc_info=e)
+            logger.exception(f'Failed getting object from object storage: {bucket_name}:{path}', exc_info=e)
 
             raise
 
@@ -145,13 +144,13 @@ async def remove_object(bucket_name: str, object_name: str):
             await s3_client.delete_object(Bucket=bucket_name, Key=object_name)
             logger.debug(f'Removed object from object storage: {bucket_name}:{object_name}')
         except Exception as e:
-            logger.error(f'Failed to remove object from object storage: {bucket_name}:{object_name}', exc_info=e)
+            logger.exception(f'Failed to remove object from object storage: {bucket_name}:{object_name}', exc_info=e)
 
             raise
 
 
 async def remove_objects(
-    bucket_name: str, prefix: str = None, object_names: Iterable[str] = None
+    bucket_name: str, prefix: str | None = None, object_names: Iterable[str] | None = None
 ) -> Sequence[Mapping] | None:
     storage = ObjectStorage(s3_settings)
 
@@ -182,9 +181,9 @@ async def remove_objects(
                     errors.extend(response['Errors'])
 
             logger.debug(f'Removed {len(objects_to_delete)} objects from object storage: {bucket_name}')
-
-            return errors if errors else None
         except Exception as e:
-            logger.error(f'Failed to remove objects from object storage: {bucket_name}', exc_info=e)
+            logger.exception(f'Failed to remove objects from object storage: {bucket_name}', exc_info=e)
 
             raise
+
+        return errors if errors else None
